<?php

function endsWith($haystack, $needle)
{
	return $needle === "" || (($temp = strlen($haystack) - strlen($needle)) >= 0 && strpos($haystack, $needle, $temp) !== FALSE);
}

if (isset($_FILES["fileToUpload"]["tmp_name"]))
{
	if ($_FILES["fileToUpload"]["size"] > 1500000)
	{
		exit('File size over 1.5 MB. Cannot load outfits.');
	}

	$monstersList = [];
	$zip = new ZipArchive();
	$errors = '';
	if ($zip->open($_FILES["fileToUpload"]["tmp_name"]) === true)
	{
		if ($zip->numFiles > 2000)
		{
			exit('Over 2000 files in ZIP. Cannot load outfits.');
		}

		for ($i = 0; $i < $zip->numFiles; $i++)
		{
			$fileName = $zip->getNameIndex($i);
			if (!endsWith($fileName, 'monsters.xml'))
			{
				$data = $zip->getFromName($fileName);
				if ($data)
				{
					$doc = new DOMDocument();
					if ($doc->loadXML($data))
					{
						$monsters = $doc->getElementsByTagName('monster');
						$looks = $doc->getElementsByTagName('look');
						if ($monsters->item(0) && $looks->item(0))
						{
							$monster = $monsters->item(0);
							$look = $looks->item(0);
							$name = $monster->getAttribute('name');
							if (empty($name))
							{
								$errors.= 'Monster without name detected. File: ' . $fileName . '<br />';
								continue;
							}

							$type = (int)$look->getAttribute('type');
							if ($type > 0)
							{
								$head = (int)$look->getAttribute('head');
								$body = (int)$look->getAttribute('body');
								$legs = (int)$look->getAttribute('legs');
								$feet = (int)$look->getAttribute('feet');
								$addons = (int)$look->getAttribute('addons');

								// add creature outfit to list

								$monstersList[] = ['img' => 'creature', 'name' => $name, 'id' => $type, 'head' => $head, 'body' => $body, 'legs' => $legs, 'feet' => $feet, 'addons' => $addons];
							}
							else
							{
								$typeEx = (int)$look->getAttribute('typeex');
								if ($typeEx > 0)
								{

									// add item outfit

									$monstersList[] = ['img' => 'item', 'name' => $name, 'id' => $typeEx];
								}
								else
								{
									$errors.= $fileName . ' - invalid outfit or item id value<br />';
									continue;
								}
							}
						}
						else
						{
							$errors.= 'Monster without name or look detected. File: ' . $fileName . '<br />';
							continue;
						}
					}
					else
					{
						$errors.= 'Failed to parse XML. File: ' . $fileName . '<br />';
						continue;
					}
				}
			}
		}
	}
	else
	{
		$errors.= 'Failed to open ZIP file. Invalid file format?<br />';
	}

	if (strlen($errors) > 0)
	{
		echo '<span style="color:red"><br />ERRORS:<br />' . $errors . '</span>';
	}

	echo '<script>
		var isUploading = false;
		function canSubmit()
		{
			if(!isUploading)
			{
				isUploading = true;
				return true;
			}
			else
			{
				alert("Generating file. Please wait.");
				return false;
			}
		}
		</script>
		<b>Found outfits of ' . count($monstersList) . ' monsters.</b><br />
		Click to get ZIP with outfit images:<br />
		This action may take few minutes. Click once and wait for download.
		<form action="getImages.php" method="post" onsubmit="return canSubmit();">
		<textarea name="data" style="width:800px;height:200px">' . json_encode($monstersList) . '</textarea><br />
		<input type="submit" value="Get Zip!" />
	</form>';
	if (strlen($errors) > 0)
	{
		echo '<span style="color:red"><br />ERRORS:<br />' . $errors . '</span>';
	}
}
else
{
	echo '<form action="index.php" method="post" enctype="multipart/form-data">
		Select file with zipped monsters folder:<br />
		<input type="file" name="fileToUpload" id="fileToUpload">
		<input type="submit" value="Send file">
	</form>';
}